@@ -167,7 +167,7 @@ cd_vec3_get_data (const CdVec3 *src)
 /**
  * cd_vec3_squared_error:
  * @src1: the vector source
- * @src1: another vector source
+ * @src2: another vector source
  *
  * Gets the mean squared error for a pair of vectors
  *
@@ -263,6 +263,31 @@ cd_mat33_determinant (const CdMat3x3 *src)
 	       src->m00 * src->m12 * src->m21;
 }
 
+/**
+ * cd_mat33_normalize:
+ * @src: the source matrix
+ * @dest: the destination matrix
+ *
+ * Normalizes a matrix
+ *
+ * The arguments @src and @dest can be the same value.
+ **/
+void
+cd_mat33_normalize (const CdMat3x3 *src, CdMat3x3 *dest)
+{
+	gdouble *data_dest;
+	gdouble *data_src;
+	gdouble det;
+	guint i;
+
+	data_src = cd_mat33_get_data (src);
+	data_dest = cd_mat33_get_data (dest);
+	det = cd_mat33_determinant (src);
+	for (i = 0; i < 9; i++)
+		data_dest[i] = data_src[i] / det;
+}
+
+
 /**
  * cd_mat33_vector_multiply:
  * @mat_src: the matrix source
