@@ -89,6 +89,7 @@ struct _CdSensorPrivate
 	gchar				*serial;
 	gchar				*model;
 	gchar				*vendor;
+	gchar				*device_path;
 	gboolean			 native;
 	gboolean			 locked;
 	gchar				**caps;
@@ -972,6 +973,15 @@ out:
 	return ret;
 }
 
+/**
+ * cd_sensor_get_device_path:
+ **/
+const gchar *
+cd_sensor_get_device_path (CdSensor *sensor)
+{
+	return sensor->priv->device_path;
+}
+
 #ifdef HAVE_GUDEV
 /**
  * cd_sensor_set_from_device:
@@ -1023,8 +1033,7 @@ cd_sensor_set_from_device (CdSensor *sensor,
 
 	/* try to get type */
 	kind_str = g_udev_device_get_property (device, "COLORD_SENSOR_KIND");
-	if (priv->kind == CD_SENSOR_KIND_UNKNOWN)
-		cd_sensor_set_kind (sensor, cd_sensor_kind_from_string (kind_str));
+	priv->kind = cd_sensor_kind_from_string (kind_str);
 	if (priv->kind == CD_SENSOR_KIND_UNKNOWN) {
 		ret = FALSE;
 		g_set_error (error, 1, 0,
@@ -1032,7 +1041,6 @@ cd_sensor_set_from_device (CdSensor *sensor,
 			     vendor_tmp, model_tmp);
 		goto out;
 	}
-	cd_sensor_set_id (sensor, kind_str);
 
 	/* get caps */
 	ret = g_udev_device_get_property_as_boolean (device,
@@ -1070,6 +1078,9 @@ cd_sensor_set_from_device (CdSensor *sensor,
 		goto out;
 	}
 
+	/* save device path */
+	priv->device_path = g_strdup (g_udev_device_get_sysfs_path (device));
+
 	/* success */
 	ret = TRUE;
 out:
@@ -1077,6 +1088,21 @@ out:
 }
 #endif
 
+/**
+ * cd_sensor_set_index:
+ **/
+void
+cd_sensor_set_index (CdSensor *sensor,
+		     guint idx)
+{
+	gchar *id;
+	id = g_strdup_printf ("%s-%02i",
+			      cd_sensor_kind_to_string (sensor->priv->kind),
+			      idx);
+	cd_sensor_set_id (sensor, id);
+	g_free (id);
+}
+
 /**
  * cd_sensor_add_option:
  **/
@@ -1294,6 +1320,7 @@ cd_sensor_finalize (GObject *object)
 	g_free (priv->vendor);
 	g_free (priv->serial);
 	g_free (priv->id);
+	g_free (priv->device_path);
 	g_free (priv->object_path);
 	g_hash_table_unref (priv->options);
 
